Module: Aws::HealthLake

Defined in:
lib/aws-sdk-healthlake/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-healthlake/plugins/endpoints.rb,
lib/aws-sdk-healthlake/endpoint_provider.rb,
lib/aws-sdk-healthlake/client_api.rb,
lib/aws-sdk-healthlake/endpoints.rb,
lib/aws-sdk-healthlake/resource.rb,
lib/aws-sdk-healthlake/waiters.rb,
lib/aws-sdk-healthlake/errors.rb,
lib/aws-sdk-healthlake/client.rb,
lib/aws-sdk-healthlake/types.rb,
lib/aws-sdk-healthlake.rb

Overview

This module provides support for Amazon HealthLake. This module is available in the aws-sdk-healthlake gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

health_lake = Aws::HealthLake::Client.new
resp = health_lake.create_fhir_datastore(params)

See Client for more information.

Errors

Errors returned from Amazon HealthLake are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::HealthLake::Errors::ServiceError
  # rescues all Amazon HealthLake API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.67.0'