Module: Aws::HealthLake::Types
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AnalyticsConfiguration, ConflictException, CreateFHIRDatastoreRequest, CreateFHIRDatastoreResponse, DatastoreFilter, DatastoreProperties, DeleteFHIRDatastoreRequest, DeleteFHIRDatastoreResponse, DescribeFHIRDatastoreRequest, DescribeFHIRDatastoreResponse, DescribeFHIRExportJobRequest, DescribeFHIRExportJobResponse, DescribeFHIRImportJobRequest, DescribeFHIRImportJobResponse, ErrorCause, ExportJobProperties, IdentityProviderConfiguration, ImportJobProperties, InputDataConfig, InternalServerException, JobProgressReport, KmsEncryptionConfig, ListFHIRDatastoresRequest, ListFHIRDatastoresResponse, ListFHIRExportJobsRequest, ListFHIRExportJobsResponse, ListFHIRImportJobsRequest, ListFHIRImportJobsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, NlpConfiguration, OutputDataConfig, PreloadDataConfig, ProfileConfiguration, ResourceNotFoundException, S3Configuration, SseConfiguration, StartFHIRExportJobRequest, StartFHIRExportJobResponse, StartFHIRImportJobRequest, StartFHIRImportJobResponse, Tag, TagResourceRequest, TagResourceResponse, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateFHIRDatastoreRequest, UpdateFHIRDatastoreResponse, ValidationException
Instance Attribute Summary collapse
-
#s3_configuration ⇒ Types::S3Configuration
The output data configuration supplied when the export job was created.
-
#s3_uri ⇒ String
The ‘S3Uri` is the user-specified S3 location of the FHIR data to be imported into AWS HealthLake.
Instance Attribute Details
#s3_configuration ⇒ Types::S3Configuration
The output data configuration supplied when the export job was created.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-healthlake/types.rb', line 923 class OutputDataConfig < Struct.new( :s3_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Configuration < OutputDataConfig; end class Unknown < OutputDataConfig; end end |
#s3_uri ⇒ String
The ‘S3Uri` is the user-specified S3 location of the FHIR data to be imported into AWS HealthLake.
604 605 606 607 608 609 610 611 612 613 |
# File 'lib/aws-sdk-healthlake/types.rb', line 604 class InputDataConfig < Struct.new( :s3_uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Uri < InputDataConfig; end class Unknown < InputDataConfig; end end |