Class: Aws::HealthLake::Types::ContinuousBackupRestoreConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::ContinuousBackupRestoreConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Configuration for continuous backup (point-in-time) restore.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#restore_point_time ⇒ Time
The point in time to restore the data store to, specified as a UTC timestamp.
Instance Attribute Details
#restore_point_time ⇒ Time
The point in time to restore the data store to, specified as a UTC timestamp.
163 164 165 166 167 |
# File 'lib/aws-sdk-healthlake/types.rb', line 163 class ContinuousBackupRestoreConfiguration < Struct.new( :restore_point_time) SENSITIVE = [] include Aws::Structure end |