Class: Aws::HealthLake::Types::CreateDataTransformationProfileSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::CreateDataTransformationProfileSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
CreateDataTransformationProfileSource is a union - when making an API calls you must set exactly one of the members.
The source for initial content when creating a data transformation profile. Specify exactly one variant: a built-in starter profile, an existing profile version to clone, raw profile content, or a sample data file.
Defined Under Namespace
Classes: ExistingVersionedProfileId, ProfileMapping, SampleData, StarterProfile, Unknown
Constant Summary collapse
- SENSITIVE =
[:profile_mapping]
Instance Attribute Summary collapse
-
#existing_versioned_profile_id ⇒ Types::ExistingVersionedProfileSource
Creates the profile by cloning an existing profile at a specific version.
-
#profile_mapping ⇒ Types::ProfileMappingSource
Creates the profile from raw profile content that you provide directly.
-
#sample_data ⇒ Types::SampleDataSource
Creates the profile from a sample data file stored in Amazon S3.
-
#starter_profile ⇒ Types::StarterProfileSource
Creates the profile from a built-in starter profile.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#existing_versioned_profile_id ⇒ Types::ExistingVersionedProfileSource
Creates the profile by cloning an existing profile at a specific version.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/aws-sdk-healthlake/types.rb', line 310 class CreateDataTransformationProfileSource < Struct.new( :starter_profile, :existing_versioned_profile_id, :profile_mapping, :sample_data, :unknown) SENSITIVE = [:profile_mapping] include Aws::Structure include Aws::Structure::Union class StarterProfile < CreateDataTransformationProfileSource; end class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end class ProfileMapping < CreateDataTransformationProfileSource; end class SampleData < CreateDataTransformationProfileSource; end class Unknown < CreateDataTransformationProfileSource; end end |
#profile_mapping ⇒ Types::ProfileMappingSource
Creates the profile from raw profile content that you provide directly. Use this variant for continuous integration and continuous delivery (CI/CD) workflows.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/aws-sdk-healthlake/types.rb', line 310 class CreateDataTransformationProfileSource < Struct.new( :starter_profile, :existing_versioned_profile_id, :profile_mapping, :sample_data, :unknown) SENSITIVE = [:profile_mapping] include Aws::Structure include Aws::Structure::Union class StarterProfile < CreateDataTransformationProfileSource; end class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end class ProfileMapping < CreateDataTransformationProfileSource; end class SampleData < CreateDataTransformationProfileSource; end class Unknown < CreateDataTransformationProfileSource; end end |
#sample_data ⇒ Types::SampleDataSource
Creates the profile from a sample data file stored in Amazon S3. Valid only when the source format is Comma-separated values (CSV).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/aws-sdk-healthlake/types.rb', line 310 class CreateDataTransformationProfileSource < Struct.new( :starter_profile, :existing_versioned_profile_id, :profile_mapping, :sample_data, :unknown) SENSITIVE = [:profile_mapping] include Aws::Structure include Aws::Structure::Union class StarterProfile < CreateDataTransformationProfileSource; end class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end class ProfileMapping < CreateDataTransformationProfileSource; end class SampleData < CreateDataTransformationProfileSource; end class Unknown < CreateDataTransformationProfileSource; end end |
#starter_profile ⇒ Types::StarterProfileSource
Creates the profile from a built-in starter profile. Valid only when the source format is Consolidated Clinical Document Architecture (C-CDA).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/aws-sdk-healthlake/types.rb', line 310 class CreateDataTransformationProfileSource < Struct.new( :starter_profile, :existing_versioned_profile_id, :profile_mapping, :sample_data, :unknown) SENSITIVE = [:profile_mapping] include Aws::Structure include Aws::Structure::Union class StarterProfile < CreateDataTransformationProfileSource; end class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end class ProfileMapping < CreateDataTransformationProfileSource; end class SampleData < CreateDataTransformationProfileSource; end class Unknown < CreateDataTransformationProfileSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
310 311 312 |
# File 'lib/aws-sdk-healthlake/types.rb', line 310 def unknown @unknown end |