Class: Aws::HealthLake::Types::CreateFHIRDatastoreRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configuration ⇒ Types::AnalyticsConfiguration

The analytics configuration for the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#backup_configuration ⇒ Types::BackupConfiguration

The backup configuration for the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

An optional user-provided token to ensure API idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_name ⇒ String

The data store name (user-generated).

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_type_version ⇒ String

The FHIR release version supported by the data store. Current support is for version R4.

Returns:

  • (String)


380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_configuration ⇒ Types::IdentityProviderConfiguration

The identity provider configuration to use for the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nlp_configuration ⇒ Types::NlpConfiguration

The natural language processing (NLP) configuration for the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#preload_data_config ⇒ Types::PreloadDataConfig

An optional parameter to preload (import) open source Synthea FHIR data upon creation of the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#profile_configuration ⇒ Types::ProfileConfiguration

The profile configuration for the data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sse_configuration ⇒ Types::SseConfiguration

The server-side encryption key configuration for a customer-provided encryption key specified for creating a data store.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The resource tags applied to a data store when it is created.

Returns:



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/aws-sdk-healthlake/types.rb', line 380

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration,
  :backup_configuration)
  SENSITIVE = []
  include Aws::Structure
end