Class: Aws::HealthLake::Types::DataTransformationProfileSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DataTransformationProfileSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Contains summary information about a data transformation profile. To
retrieve profile content, call GetDataTransformationProfile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_at ⇒ Time
The timestamp when the profile was last updated.
-
#profile_description ⇒ String
A description of the profile's purpose.
-
#profile_id ⇒ String
The unique identifier of the profile.
-
#profile_name ⇒ String
The name of the profile.
-
#source_format ⇒ String
The source data format that this profile converts from.
-
#target_format ⇒ String
The target output format of the profile.
-
#version ⇒ Integer
The latest version number of the profile.
Instance Attribute Details
#last_updated_at ⇒ Time
The timestamp when the profile was last updated.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_description ⇒ String
A description of the profile's purpose.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the profile.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_name ⇒ String
The name of the profile.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#source_format ⇒ String
The source data format that this profile converts from.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#target_format ⇒ String
The target output format of the profile.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The latest version number of the profile.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-healthlake/types.rb', line 407 class DataTransformationProfileSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :profile_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |