Class: Aws::HealthLake::Types::DataTransformationProfileVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Contains summary information about a specific version of a data transformation profile. To retrieve profile content, call GetDataTransformationProfile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_description ⇒ String

A description of what changed in this version.

Returns:

  • (String)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The timestamp when this version was last updated.

Returns:

  • (Time)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_id ⇒ String

The unique identifier of the profile.

Returns:

  • (String)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_name ⇒ String

The name of the profile.

Returns:

  • (String)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#source_format ⇒ String

The source data format that this profile converts from.

Returns:

  • (String)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_format ⇒ String

The target output format of the profile.

Returns:

  • (String)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ Integer

The version number.

Returns:

  • (Integer)


502
503
504
505
506
507
508
509
510
511
512
# File 'lib/aws-sdk-healthlake/types.rb', line 502

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end