Class: Aws::HealthLake::Types::DeleteFHIRDatastoreResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DeleteFHIRDatastoreResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) that grants access permission to HealthLake.
-
#datastore_endpoint ⇒ String
The Amazon Web Services endpoint of the data store to be deleted.
-
#datastore_id ⇒ String
The Amazon Web Services-generated ID for the deleted data store.
-
#datastore_status ⇒ String
The data store status.
Instance Attribute Details
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) that grants access permission to HealthLake.
762 763 764 765 766 767 768 769 |
# File 'lib/aws-sdk-healthlake/types.rb', line 762 class DeleteFHIRDatastoreResponse < Struct.new( :datastore_id, :datastore_arn, :datastore_status, :datastore_endpoint) SENSITIVE = [] include Aws::Structure end |
#datastore_endpoint ⇒ String
The Amazon Web Services endpoint of the data store to be deleted.
762 763 764 765 766 767 768 769 |
# File 'lib/aws-sdk-healthlake/types.rb', line 762 class DeleteFHIRDatastoreResponse < Struct.new( :datastore_id, :datastore_arn, :datastore_status, :datastore_endpoint) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The Amazon Web Services-generated ID for the deleted data store.
762 763 764 765 766 767 768 769 |
# File 'lib/aws-sdk-healthlake/types.rb', line 762 class DeleteFHIRDatastoreResponse < Struct.new( :datastore_id, :datastore_arn, :datastore_status, :datastore_endpoint) SENSITIVE = [] include Aws::Structure end |
#datastore_status ⇒ String
The data store status.
762 763 764 765 766 767 768 769 |
# File 'lib/aws-sdk-healthlake/types.rb', line 762 class DeleteFHIRDatastoreResponse < Struct.new( :datastore_id, :datastore_arn, :datastore_status, :datastore_endpoint) SENSITIVE = [] include Aws::Structure end |