Class: Aws::HealthLake::Types::DescribeDataTransformationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DescribeDataTransformationJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The request parameters for the DescribeDataTransformationJob
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier of the data transformation job to describe.
Instance Attribute Details
#job_id ⇒ String
The unique identifier of the data transformation job to describe.
689 690 691 692 693 |
# File 'lib/aws-sdk-healthlake/types.rb', line 689 class DescribeDataTransformationJobRequest < Struct.new( :job_id) SENSITIVE = [] include Aws::Structure end |