Class: Aws::HealthLake::Types::DescribeDataTransformationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DescribeDataTransformationJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The response from the DescribeDataTransformationJob operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#transformation_job_properties ⇒ Types::TransformationJobProperties
The properties of the data transformation job, including status, configuration, and progress information.
Instance Attribute Details
#transformation_job_properties ⇒ Types::TransformationJobProperties
The properties of the data transformation job, including status, configuration, and progress information.
704 705 706 707 708 |
# File 'lib/aws-sdk-healthlake/types.rb', line 704 class DescribeDataTransformationJobResponse < Struct.new( :transformation_job_properties) SENSITIVE = [] include Aws::Structure end |