Class: Aws::HealthLake::Types::ExistingVersionedProfileSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Identifies an existing data transformation profile and version to clone when creating a new profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#profile_id ⇒ String

The unique identifier of the existing profile to clone from.

Returns:

  • (String)


917
918
919
920
921
922
# File 'lib/aws-sdk-healthlake/types.rb', line 917

class ExistingVersionedProfileSource < Struct.new(
  :profile_id,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ Integer

The version number of the existing profile to clone from.

Returns:

  • (Integer)


917
918
919
920
921
922
# File 'lib/aws-sdk-healthlake/types.rb', line 917

class ExistingVersionedProfileSource < Struct.new(
  :profile_id,
  :version)
  SENSITIVE = []
  include Aws::Structure
end