Class: Aws::HealthLake::Types::ExportJobProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The properties of a FHIR export job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_role_arn ⇒ String

The Amazon Resource Name (ARN) used during the initiation of the export job.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_id ⇒ String

The data store identifier from which files are being exported.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ Time

The time the export job completed.

Returns:

  • (Time)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_id ⇒ String

The export job identifier.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_name ⇒ String

The export job name.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_status ⇒ String

The export job status.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

An explanation of any errors that might have occurred during the export job.

Returns:

  • (String)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_config ⇒ Types::OutputDataConfig

The output data configuration supplied when the export job was created.



967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#submit_time ⇒ Time

The time the export job was initiated.

Returns:

  • (Time)


967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/aws-sdk-healthlake/types.rb', line 967

class ExportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :output_data_config,
  :data_access_role_arn,
  :message)
  SENSITIVE = []
  include Aws::Structure
end