Class: Aws::HealthLake::Types::GetDataTransformationProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::GetDataTransformationProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The response from the GetDataTransformationProfile operation.
Constant Summary collapse
- SENSITIVE =
[:profile_mapping]
Instance Attribute Summary collapse
-
#change_description ⇒ String
A description of what changed in this version.
-
#last_updated_at ⇒ Time
The timestamp when this version was last updated.
-
#profile_description ⇒ String
The description of the profile.
-
#profile_id ⇒ String
The unique identifier of the profile.
-
#profile_mapping ⇒ Hash<String,String>
The profile content as a map of file paths to content strings.
-
#profile_name ⇒ String
The name of the profile.
-
#source_format ⇒ String
The source data format of the profile.
-
#target_format ⇒ String
The target output format of the profile.
-
#version ⇒ Integer
The version number of the retrieved profile.
Instance Attribute Details
#change_description ⇒ String
A description of what changed in this version.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp when this version was last updated.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#profile_description ⇒ String
The description of the profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#profile_mapping ⇒ Hash<String,String>
The profile content as a map of file paths to content strings.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#profile_name ⇒ String
The name of the profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#source_format ⇒ String
The source data format of the profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#target_format ⇒ String
The target output format of the profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |
#version ⇒ Integer
The version number of the retrieved profile.
966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/aws-sdk-healthlake/types.rb', line 966 class GetDataTransformationProfileResponse < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_mapping, :profile_name, :profile_description, :change_description, :last_updated_at) SENSITIVE = [:profile_mapping] include Aws::Structure end |