Class: Aws::HealthLake::Types::ImportJobProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The import job properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_role_arnString

The Amazon Resource Name (ARN) that grants AWS HealthLake access to the input data.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time the import job was completed.

Returns:

  • (Time)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::InputDataConfig

The input data configuration supplied when the import job was created.



1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The import job identifier.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The import job name.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_output_data_configTypes::OutputDataConfig

The output data configuration supplied when the export job was created.



1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_progress_reportTypes::JobProgressReport

Displays the progress of the import job, including total resources scanned, total resources imported, and total size of data imported.



1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The import job status.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

An explanation of any errors that might have occurred during the FHIR import job.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#submit_timeTime

The time the import job was submitted for processing.

Returns:

  • (Time)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#validation_levelString

The validation level of the import job.

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/aws-sdk-healthlake/types.rb', line 1111

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end