Class: Aws::HealthLake::Types::InputDataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::InputDataConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Note:
InputDataConfig is a union - when making an API calls you must set exactly one of the members.
Note:
InputDataConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InputDataConfig corresponding to the set member.
The import job input properties.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_uri ⇒ String
The ‘S3Uri` is the user-specified S3 location of the FHIR data to be imported into AWS HealthLake.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3_uri ⇒ String
The ‘S3Uri` is the user-specified S3 location of the FHIR data to be imported into AWS HealthLake.
621 622 623 624 625 626 627 628 629 630 |
# File 'lib/aws-sdk-healthlake/types.rb', line 621 class InputDataConfig < Struct.new( :s3_uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Uri < InputDataConfig; end class Unknown < InputDataConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
621 622 623 |
# File 'lib/aws-sdk-healthlake/types.rb', line 621 def unknown @unknown end |