Class: Aws::HealthLake::Types::KmsEncryptionConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The customer-managed-key (CMK) used when creating a data store. If a customer-owned key is not specified, an Amazon Web Services-owned key is used for encryption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cmk_type ⇒ String

The type of customer-managed-key (CMK) used for encryption.

Returns:

  • (String)


1377
1378
1379
1380
1381
1382
# File 'lib/aws-sdk-healthlake/types.rb', line 1377

class KmsEncryptionConfig < Struct.new(
  :cmk_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The Key Management Service (KMS) encryption key id/alias used to encrypt the data store contents at rest.

Returns:

  • (String)


1377
1378
1379
1380
1381
1382
# File 'lib/aws-sdk-healthlake/types.rb', line 1377

class KmsEncryptionConfig < Struct.new(
  :cmk_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end