Class: Aws::HealthLake::Types::OutputDataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::OutputDataConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Note:
OutputDataConfig is a union - when making an API calls you must set exactly one of the members.
Note:
OutputDataConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OutputDataConfig corresponding to the set member.
The output data configuration supplied when the export job was created.
Direct Known Subclasses
Defined Under Namespace
Classes: S3Configuration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_configuration ⇒ Types::S3Configuration
The output data configuration supplied when the export job was created.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3_configuration ⇒ Types::S3Configuration
The output data configuration supplied when the export job was created.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-healthlake/types.rb', line 923 class OutputDataConfig < Struct.new( :s3_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Configuration < OutputDataConfig; end class Unknown < OutputDataConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
923 924 925 |
# File 'lib/aws-sdk-healthlake/types.rb', line 923 def unknown @unknown end |