Class: Aws::HealthLake::Types::ProfileConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::ProfileConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
<para>The profile configuration for a data store.</para>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_profiles ⇒ Array<String>
<para>The list of default profiles for the data store.</para>.
Instance Attribute Details
#default_profiles ⇒ Array<String>
<para>The list of default profiles for the data store.</para>
957 958 959 960 961 |
# File 'lib/aws-sdk-healthlake/types.rb', line 957 class ProfileConfiguration < Struct.new( :default_profiles) SENSITIVE = [] include Aws::Structure end |