Class: Aws::HealthLake::Types::RestoreConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Note:

RestoreConfiguration is a union - when making an API calls you must set exactly one of the members.

Specifies the type and parameters for the restore operation.

Defined Under Namespace

Classes: ContinuousBackupRestoreConfiguration, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#continuous_backup_restore_configuration ⇒ Types::ContinuousBackupRestoreConfiguration

Configuration for restoring from continuous backup to a specific point in time.



1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
# File 'lib/aws-sdk-healthlake/types.rb', line 1932

class RestoreConfiguration < Struct.new(
  :continuous_backup_restore_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ContinuousBackupRestoreConfiguration < RestoreConfiguration; end
  class Unknown < RestoreConfiguration; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



1932
1933
1934
# File 'lib/aws-sdk-healthlake/types.rb', line 1932

def unknown
  @unknown
end