Class: Aws::HealthLake::Types::RestoreFHIRDatastoreRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configuration ⇒ Types::AnalyticsConfiguration

The analytics configuration for the restored data store.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

An optional user-provided token to ensure API idempotency of the restore.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_name ⇒ String

The name for the restored data store.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_configuration ⇒ Types::IdentityProviderConfiguration

The identity provider configuration for the restored data store.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nlp_configuration ⇒ Types::NlpConfiguration

The NLP configuration for the restored data store.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#profile_configuration ⇒ Types::ProfileConfiguration

The profile configuration for the restored data store.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#restore_configuration ⇒ Types::RestoreConfiguration

The restore configuration specifying the type and parameters for the restore.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_datastore_id ⇒ String

The identifier of the source data store to restore from.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sse_configuration ⇒ Types::SseConfiguration

The server-side encryption key configuration for the restored data store.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The resource tags applied to the restored data store.

Returns:



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
# File 'lib/aws-sdk-healthlake/types.rb', line 1991

class RestoreFHIRDatastoreRequest < Struct.new(
  :source_datastore_id,
  :restore_configuration,
  :datastore_name,
  :sse_configuration,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end