Class: Aws::HealthLake::Types::SseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::SseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The server-side encryption key configuration for a customer-provided encryption key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_encryption_config ⇒ Types::KmsEncryptionConfig
The Key Management Service (KMS) encryption configuration used to provide details for data encryption.
Instance Attribute Details
#kms_encryption_config ⇒ Types::KmsEncryptionConfig
The Key Management Service (KMS) encryption configuration used to provide details for data encryption.
1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1008 class SseConfiguration < Struct.new( :kms_encryption_config) SENSITIVE = [] include Aws::Structure end |