Class: Aws::HealthLake::Types::StartDataTransformationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::StartDataTransformationJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The response from the StartDataTransformationJob operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_id ⇒ String
The unique identifier assigned to the data transformation job.
-
#job_status ⇒ String
The initial status of the data transformation job.
Instance Attribute Details
#job_id ⇒ String
The unique identifier assigned to the data transformation job.
1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1969 class StartDataTransformationJobResponse < Struct.new( :job_id, :job_status) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The initial status of the data transformation job.
1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1969 class StartDataTransformationJobResponse < Struct.new( :job_id, :job_status) SENSITIVE = [] include Aws::Structure end |