Class: Aws::HealthLake::Types::StartFHIRExportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

An optional user provided token used for ensuring API idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/aws-sdk-healthlake/types.rb', line 2209

class StartFHIRExportJobRequest < Struct.new(
  :job_name,
  :output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#data_access_role_arn ⇒ String

The Amazon Resource Name (ARN) used during initiation of the export job.

Returns:

  • (String)


2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/aws-sdk-healthlake/types.rb', line 2209

class StartFHIRExportJobRequest < Struct.new(
  :job_name,
  :output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_id ⇒ String

The data store identifier from which files are being exported.

Returns:

  • (String)


2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/aws-sdk-healthlake/types.rb', line 2209

class StartFHIRExportJobRequest < Struct.new(
  :job_name,
  :output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_name ⇒ String

The export job name.

Returns:

  • (String)


2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/aws-sdk-healthlake/types.rb', line 2209

class StartFHIRExportJobRequest < Struct.new(
  :job_name,
  :output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_config ⇒ Types::OutputDataConfig

The output data configuration supplied when the export job was started.



2209
2210
2211
2212
2213
2214
2215
2216
2217
# File 'lib/aws-sdk-healthlake/types.rb', line 2209

class StartFHIRExportJobRequest < Struct.new(
  :job_name,
  :output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end