Class: Aws::HealthLake::Types::StartFHIRExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::StartFHIRExportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#datastore_id ⇒ String
The data store identifier from which files are being exported.
-
#job_id ⇒ String
The export job identifier.
-
#job_status ⇒ String
The export job status.
Instance Attribute Details
#datastore_id ⇒ String
The data store identifier from which files are being exported.
1082 1083 1084 1085 1086 1087 1088 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1082 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The export job identifier.
1082 1083 1084 1085 1086 1087 1088 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1082 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The export job status.
1082 1083 1084 1085 1086 1087 1088 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1082 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |