Class: Aws::HealthLake::Types::StartFHIRImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

The optional user-provided token used for ensuring API idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#data_access_role_arn ⇒ String

The Amazon Resource Name (ARN) that grants access permission to HealthLake.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_id ⇒ String

The data store identifier.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#drift_detection_enabled ⇒ Boolean

Specifies whether to enable drift detection for the import job.

Returns:

  • (Boolean)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_config ⇒ Types::InputDataConfig

The input properties for the import job request.



2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#input_format ⇒ String

The input format of the data to be imported.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_name ⇒ String

The import job name.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_output_data_config ⇒ Types::OutputDataConfig

The output data configuration supplied when the export job was created.



2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#profile_id ⇒ String

The data transformation profile identifier to use for the import job.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provenance_enabled ⇒ Boolean

Specifies whether to enable provenance for the import job.

Returns:

  • (Boolean)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#validation_level ⇒ String

The validation level of the import job.

Returns:

  • (String)


2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
# File 'lib/aws-sdk-healthlake/types.rb', line 2293

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end