Class: Aws::HealthLake::Types::StarterProfileSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Identifies a built-in starter profile to use as the source when creating a data transformation profile. Valid only when the source format is Consolidated Clinical Document Architecture (C-CDA).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#starter_profile_nameString

The name of the built-in starter profile.

Returns:

  • (String)


2134
2135
2136
2137
2138
# File 'lib/aws-sdk-healthlake/types.rb', line 2134

class StarterProfileSource < Struct.new(
  :starter_profile_name)
  SENSITIVE = []
  include Aws::Structure
end