Class: Aws::HealthLake::Types::TransformationJobProgressReport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Contains progress metrics for a data transformation job, including counts of files scanned, converted, and failed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#total_files_converted ⇒ Integer

The total number of source files successfully converted.

Returns:

  • (Integer)


2447
2448
2449
2450
2451
2452
2453
2454
# File 'lib/aws-sdk-healthlake/types.rb', line 2447

class TransformationJobProgressReport < Struct.new(
  :total_files_scanned,
  :total_files_converted,
  :total_files_failed,
  :total_resources_generated)
  SENSITIVE = []
  include Aws::Structure
end

#total_files_failed ⇒ Integer

The total number of source files that failed conversion.

Returns:

  • (Integer)


2447
2448
2449
2450
2451
2452
2453
2454
# File 'lib/aws-sdk-healthlake/types.rb', line 2447

class TransformationJobProgressReport < Struct.new(
  :total_files_scanned,
  :total_files_converted,
  :total_files_failed,
  :total_resources_generated)
  SENSITIVE = []
  include Aws::Structure
end

#total_files_scanned ⇒ Integer

The total number of source files scanned by the job.

Returns:

  • (Integer)


2447
2448
2449
2450
2451
2452
2453
2454
# File 'lib/aws-sdk-healthlake/types.rb', line 2447

class TransformationJobProgressReport < Struct.new(
  :total_files_scanned,
  :total_files_converted,
  :total_files_failed,
  :total_resources_generated)
  SENSITIVE = []
  include Aws::Structure
end

#total_resources_generated ⇒ Integer

The total number of FHIR R4 resources generated across all converted files.

Returns:

  • (Integer)


2447
2448
2449
2450
2451
2452
2453
2454
# File 'lib/aws-sdk-healthlake/types.rb', line 2447

class TransformationJobProgressReport < Struct.new(
  :total_files_scanned,
  :total_files_converted,
  :total_files_failed,
  :total_resources_generated)
  SENSITIVE = []
  include Aws::Structure
end