Class: Aws::HealthLake::Waiters::FHIRDatastoreDeleted
- Inherits:
-
Object
- Object
- Aws::HealthLake::Waiters::FHIRDatastoreDeleted
- Defined in:
- lib/aws-sdk-healthlake/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FHIRDatastoreDeleted
constructor
A new instance of FHIRDatastoreDeleted.
-
#wait(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FHIRDatastoreDeleted
Returns a new instance of FHIRDatastoreDeleted.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 137 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 360, delay: 120, poller: Aws::Waiters::Poller.new( operation_name: :describe_fhir_datastore, acceptors: [{ "state" => "success", "matcher" => "path", "argument" => "datastore_properties.datastore_status", "expected" => "DELETED" }] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
161 162 163 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 161 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Returns a response object which responds to the following methods:
-
#datastore_properties => Types::DatastoreProperties
156 157 158 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 156 def wait(params = {}) @waiter.wait(client: @client, params: params) end |