Class: Aws::HealthLake::Waiters::FHIRImportJobCompleted
- Inherits:
-
Object
- Object
- Aws::HealthLake::Waiters::FHIRImportJobCompleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-healthlake/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FHIRImportJobCompleted
constructor
A new instance of FHIRImportJobCompleted.
-
#wait(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FHIRImportJobCompleted
Returns a new instance of FHIRImportJobCompleted.
235 236 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 235
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
273 274 275 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 273 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Returns a response object which responds to the following methods:
- #import_job_properties => Types::ImportJobProperties
268 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 268
def wait: (
|