Class: Aws::HealthLake::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::HealthLake::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-healthlake/client.rb,
sig/client.rbs
Overview
An API client for HealthLake. To construct a client, you need to configure a :region and :credentials.
client = Aws::HealthLake::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateDataTransformationProfileResponseSuccess, _CreateFHIRDatastoreResponseSuccess, _DeleteDataTransformationProfileResponseSuccess, _DeleteFHIRDatastoreResponseSuccess, _DescribeDataTransformationJobResponseSuccess, _DescribeFHIRDatastoreResponseSuccess, _DescribeFHIRExportJobResponseSuccess, _DescribeFHIRImportJobResponseSuccess, _GetDataTransformationProfileResponseSuccess, _ListDataTransformationJobsResponseSuccess, _ListDataTransformationProfileVersionsResponseSuccess, _ListDataTransformationProfilesResponseSuccess, _ListFHIRDatastoresResponseSuccess, _ListFHIRExportJobsResponseSuccess, _ListFHIRImportJobsResponseSuccess, _ListTagsForResourceResponseSuccess, _PublishDataTransformationProfileResponseSuccess, _StartDataTransformationJobResponseSuccess, _StartFHIRExportJobResponseSuccess, _StartFHIRImportJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDataTransformationProfileResponseSuccess, _UpdateFHIRDatastoreResponseSuccess, _UpdateProfileWithAgentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_data_transformation_profile(params = {}) ⇒ Types::CreateDataTransformationProfileResponse
Creates a data transformation profile in DRAFT state.
-
#create_fhir_datastore(params = {}) ⇒ Types::CreateFHIRDatastoreResponse
Create a FHIR-enabled data store.
-
#delete_data_transformation_profile(params = {}) ⇒ Types::DeleteDataTransformationProfileResponse
Deletes a data transformation profile and all its versions, including the DRAFT and all published versions.
-
#delete_fhir_datastore(params = {}) ⇒ Types::DeleteFHIRDatastoreResponse
Delete a FHIR-enabled data store.
-
#describe_data_transformation_job(params = {}) ⇒ Types::DescribeDataTransformationJobResponse
Describes a data transformation job, including its current status, configuration, and progress information.
-
#describe_fhir_datastore(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Get properties for a FHIR-enabled data store.
-
#describe_fhir_export_job(params = {}) ⇒ Types::DescribeFHIRExportJobResponse
Get FHIR export job properties.
-
#describe_fhir_import_job(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Get the import job properties to learn more about the job or job progress.
-
#get_data_transformation_profile(params = {}) ⇒ Types::GetDataTransformationProfileResponse
Retrieves a data transformation profile's metadata and profile content at a specific version.
-
#list_data_transformation_jobs(params = {}) ⇒ Types::ListDataTransformationJobsResponse
Lists data transformation jobs for your AWS account.
-
#list_data_transformation_profile_versions(params = {}) ⇒ Types::ListDataTransformationProfileVersionsResponse
Lists all versions of a specific data transformation profile (DRAFT and published), in reverse chronological order (newest first).
-
#list_data_transformation_profiles(params = {}) ⇒ Types::ListDataTransformationProfilesResponse
Lists all data transformation profiles in your account, returning the latest version summary for each.
-
#list_fhir_datastores(params = {}) ⇒ Types::ListFHIRDatastoresResponse
List all FHIR-enabled data stores in a user’s account, regardless of data store status.
-
#list_fhir_export_jobs(params = {}) ⇒ Types::ListFHIRExportJobsResponse
Lists all FHIR export jobs associated with an account and their statuses.
-
#list_fhir_import_jobs(params = {}) ⇒ Types::ListFHIRImportJobsResponse
List all FHIR import jobs associated with an account and their statuses.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all existing tags associated with a data store.
-
#publish_data_transformation_profile(params = {}) ⇒ Types::PublishDataTransformationProfileResponse
Promotes the current DRAFT version of a data transformation profile to a new immutable published version.
-
#start_data_transformation_job(params = {}) ⇒ Types::StartDataTransformationJobResponse
Starts an asynchronous data transformation job that converts source files from Amazon Simple Storage Service (Amazon S3) and writes the output to Amazon S3 or AWS HealthLake.
-
#start_fhir_export_job(params = {}) ⇒ Types::StartFHIRExportJobResponse
Start a FHIR export job.
-
#start_fhir_import_job(params = {}) ⇒ Types::StartFHIRImportJobResponse
Start importing bulk FHIR data into an ACTIVE data store.
-
#tag_resource(params = {}) ⇒ Struct
Add a user-specifed key and value tag to a data store.
-
#untag_resource(params = {}) ⇒ Struct
Remove a user-specifed key and value tag from a data store.
-
#update_data_transformation_profile(params = {}) ⇒ Types::UpdateDataTransformationProfileResponse
Updates the DRAFT version (version 0) of a data transformation profile with new profile content.
-
#update_fhir_datastore(params = {}) ⇒ Types::UpdateFHIRDatastoreResponse
Update the properties of a FHIR-enabled data store.
-
#update_profile_with_agent(params = {}) ⇒ Types::UpdateProfileWithAgentResponse
Updates a data transformation profile using chat-based interaction with an agent.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-healthlake/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2117 2118 2119 |
# File 'lib/aws-sdk-healthlake/client.rb', line 2117 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2120 2121 2122 |
# File 'lib/aws-sdk-healthlake/client.rb', line 2120 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1969 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::HealthLake') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-healthlake' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_data_transformation_profile(params = {}) ⇒ Types::CreateDataTransformationProfileResponse
Creates a data transformation profile in DRAFT state. Specify a built-in starter profile, an existing profile version, raw profile content, or a sample data file as the source.
92 |
# File 'sig/client.rbs', line 92
def create_data_transformation_profile: (
|
#create_fhir_datastore(params = {}) ⇒ Types::CreateFHIRDatastoreResponse
Create a FHIR-enabled data store.
125 |
# File 'sig/client.rbs', line 125
def create_fhir_datastore: (
|
#delete_data_transformation_profile(params = {}) ⇒ Types::DeleteDataTransformationProfileResponse
Deletes a data transformation profile and all its versions, including the DRAFT and all published versions.
169 |
# File 'sig/client.rbs', line 169
def delete_data_transformation_profile: (
|
#delete_fhir_datastore(params = {}) ⇒ Types::DeleteFHIRDatastoreResponse
Delete a FHIR-enabled data store.
182 |
# File 'sig/client.rbs', line 182
def delete_fhir_datastore: (
|
#describe_data_transformation_job(params = {}) ⇒ Types::DescribeDataTransformationJobResponse
Describes a data transformation job, including its current status, configuration, and progress information.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* data_transformation_job_completed
192 |
# File 'sig/client.rbs', line 192
def describe_data_transformation_job: (
|
#describe_fhir_datastore(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Get properties for a FHIR-enabled data store.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_datastore_active
* fhir_datastore_deleted
202 |
# File 'sig/client.rbs', line 202
def describe_fhir_datastore: (
|
#describe_fhir_export_job(params = {}) ⇒ Types::DescribeFHIRExportJobResponse
Get FHIR export job properties.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_export_job_completed
212 |
# File 'sig/client.rbs', line 212
def describe_fhir_export_job: (
|
#describe_fhir_import_job(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Get the import job properties to learn more about the job or job progress.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_import_job_completed
223 |
# File 'sig/client.rbs', line 223
def describe_fhir_import_job: (
|
#get_data_transformation_profile(params = {}) ⇒ Types::GetDataTransformationProfileResponse
Retrieves a data transformation profile's metadata and profile content at a specific version. Specify version 0 to retrieve the DRAFT, a version number between 1 and 99 to retrieve a specific published version, or omit the version to retrieve the latest published version.
242 |
# File 'sig/client.rbs', line 242
def get_data_transformation_profile: (
|
#list_data_transformation_jobs(params = {}) ⇒ Types::ListDataTransformationJobsResponse
Lists data transformation jobs for your AWS account. Results can be
filtered by status, job name, and submit time window. Results are
paginated. Use the NextToken parameter to retrieve additional
results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
254 |
# File 'sig/client.rbs', line 254
def list_data_transformation_jobs: (
|
#list_data_transformation_profile_versions(params = {}) ⇒ Types::ListDataTransformationProfileVersionsResponse
Lists all versions of a specific data transformation profile (DRAFT
and published), in reverse chronological order (newest first). Use
GetDataTransformationProfile to retrieve profile content. Results
are paginated. Use the NextToken parameter to retrieve additional
results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
270 |
# File 'sig/client.rbs', line 270
def list_data_transformation_profile_versions: (
|
#list_data_transformation_profiles(params = {}) ⇒ Types::ListDataTransformationProfilesResponse
Lists all data transformation profiles in your account, returning the
latest version summary for each. Use GetDataTransformationProfile to
retrieve profile content. Results are paginated. Use the NextToken
parameter to retrieve additional results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
283 |
# File 'sig/client.rbs', line 283
def list_data_transformation_profiles: (
|
#list_fhir_datastores(params = {}) ⇒ Types::ListFHIRDatastoresResponse
List all FHIR-enabled data stores in a user’s account, regardless of data store status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
296 |
# File 'sig/client.rbs', line 296
def list_fhir_datastores: (
|
#list_fhir_export_jobs(params = {}) ⇒ Types::ListFHIRExportJobsResponse
Lists all FHIR export jobs associated with an account and their statuses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def list_fhir_export_jobs: (
|
#list_fhir_import_jobs(params = {}) ⇒ Types::ListFHIRImportJobsResponse
List all FHIR import jobs associated with an account and their statuses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
331 |
# File 'sig/client.rbs', line 331
def list_fhir_import_jobs: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all existing tags associated with a data store.
347 |
# File 'sig/client.rbs', line 347
def list_tags_for_resource: (
|
#publish_data_transformation_profile(params = {}) ⇒ Types::PublishDataTransformationProfileResponse
Promotes the current DRAFT version of a data transformation profile to a new immutable published version. Also supports rollback by publishing from a previously published version.
362 |
# File 'sig/client.rbs', line 362
def publish_data_transformation_profile: (
|
#start_data_transformation_job(params = {}) ⇒ Types::StartDataTransformationJobResponse
Starts an asynchronous data transformation job that converts source files from Amazon Simple Storage Service (Amazon S3) and writes the output to Amazon S3 or AWS HealthLake.
376 |
# File 'sig/client.rbs', line 376
def start_data_transformation_job: (
|
#start_fhir_export_job(params = {}) ⇒ Types::StartFHIRExportJobResponse
Start a FHIR export job.
403 |
# File 'sig/client.rbs', line 403
def start_fhir_export_job: (
|
#start_fhir_import_job(params = {}) ⇒ Types::StartFHIRImportJobResponse
Start importing bulk FHIR data into an ACTIVE data store. The import
job imports FHIR data found in the InputDataConfig object and stores
processing results in the JobOutputDataConfig object.
424 |
# File 'sig/client.rbs', line 424
def start_fhir_import_job: (
|
#tag_resource(params = {}) ⇒ Struct
Add a user-specifed key and value tag to a data store.
450 |
# File 'sig/client.rbs', line 450
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove a user-specifed key and value tag from a data store.
465 |
# File 'sig/client.rbs', line 465
def untag_resource: (
|
#update_data_transformation_profile(params = {}) ⇒ Types::UpdateDataTransformationProfileResponse
Updates the DRAFT version (version 0) of a data transformation profile with new profile content. The update replaces all existing DRAFT content.
480 |
# File 'sig/client.rbs', line 480
def update_data_transformation_profile: (
|
#update_fhir_datastore(params = {}) ⇒ Types::UpdateFHIRDatastoreResponse
Update the properties of a FHIR-enabled data store.
492 |
# File 'sig/client.rbs', line 492
def update_fhir_datastore: (
|
#update_profile_with_agent(params = {}) ⇒ Types::UpdateProfileWithAgentResponse
Updates a data transformation profile using chat-based interaction with an agent. Supports multi-turn conversations for iteratively customizing profiles.
519 |
# File 'sig/client.rbs', line 519
def update_profile_with_agent: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| data_transformation_job_completed | #describe_data_transformation_job | 30 | 5 |
| fhir_datastore_active | #describe_fhir_datastore | 60 | 5 |
| fhir_datastore_deleted | #describe_fhir_datastore | 120 | 5 |
| fhir_export_job_completed | #describe_fhir_export_job | 120 | 5 |
| fhir_import_job_completed | #describe_fhir_import_job | 120 | 5 |
531 |
# File 'sig/client.rbs', line 531
def wait_until: (:data_transformation_job_completed waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2087 2088 2089 |
# File 'lib/aws-sdk-healthlake/client.rb', line 2087 def waiter_names waiters.keys end |