Class: Aws::HealthLake::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::HealthLake::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-healthlake/client.rb
Overview
An API client for HealthLake. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::HealthLake::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_fhir_datastore(params = {}) ⇒ Types::CreateFHIRDatastoreResponse
Create a FHIR-enabled data store.
-
#delete_fhir_datastore(params = {}) ⇒ Types::DeleteFHIRDatastoreResponse
Delete a FHIR-enabled data store.
-
#describe_fhir_datastore(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Get properties for a FHIR-enabled data store.
-
#describe_fhir_export_job(params = {}) ⇒ Types::DescribeFHIRExportJobResponse
Get FHIR export job properties.
-
#describe_fhir_import_job(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Get the import job properties to learn more about the job or job progress.
-
#list_fhir_datastores(params = {}) ⇒ Types::ListFHIRDatastoresResponse
List all FHIR-enabled data stores in a user’s account, regardless of data store status.
-
#list_fhir_export_jobs(params = {}) ⇒ Types::ListFHIRExportJobsResponse
Lists all FHIR export jobs associated with an account and their statuses.
-
#list_fhir_import_jobs(params = {}) ⇒ Types::ListFHIRImportJobsResponse
List all FHIR import jobs associated with an account and their statuses.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all existing tags associated with a data store.
-
#start_fhir_export_job(params = {}) ⇒ Types::StartFHIRExportJobResponse
Start a FHIR export job.
-
#start_fhir_import_job(params = {}) ⇒ Types::StartFHIRImportJobResponse
Start importing bulk FHIR data into an ACTIVE data store.
-
#tag_resource(params = {}) ⇒ Struct
Add a user-specifed key and value tag to a data store.
-
#untag_resource(params = {}) ⇒ Struct
Remove a user-specifed key and value tag from a data store.
-
#update_fhir_datastore(params = {}) ⇒ Types::UpdateFHIRDatastoreResponse
<para>Update the properties of a FHIR-enabled data store.</para>.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-healthlake/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1423 1424 1425 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1423 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1426 1427 1428 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1426 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1277 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::HealthLake') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-healthlake' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#create_fhir_datastore(params = {}) ⇒ Types::CreateFHIRDatastoreResponse
Create a FHIR-enabled data store.
560 561 562 563 |
# File 'lib/aws-sdk-healthlake/client.rb', line 560 def create_fhir_datastore(params = {}, = {}) req = build_request(:create_fhir_datastore, params) req.send_request() end |
#delete_fhir_datastore(params = {}) ⇒ Types::DeleteFHIRDatastoreResponse
Delete a FHIR-enabled data store.
594 595 596 597 |
# File 'lib/aws-sdk-healthlake/client.rb', line 594 def delete_fhir_datastore(params = {}, = {}) req = build_request(:delete_fhir_datastore, params) req.send_request() end |
#describe_fhir_datastore(params = {}) ⇒ Types::DescribeFHIRDatastoreResponse
Get properties for a FHIR-enabled data store.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_datastore_active
* fhir_datastore_deleted
647 648 649 650 |
# File 'lib/aws-sdk-healthlake/client.rb', line 647 def describe_fhir_datastore(params = {}, = {}) req = build_request(:describe_fhir_datastore, params) req.send_request() end |
#describe_fhir_export_job(params = {}) ⇒ Types::DescribeFHIRExportJobResponse
Get FHIR export job properties.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_export_job_completed
693 694 695 696 |
# File 'lib/aws-sdk-healthlake/client.rb', line 693 def describe_fhir_export_job(params = {}, = {}) req = build_request(:describe_fhir_export_job, params) req.send_request() end |
#describe_fhir_import_job(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Get the import job properties to learn more about the job or job progress.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fhir_import_job_completed
750 751 752 753 |
# File 'lib/aws-sdk-healthlake/client.rb', line 750 def describe_fhir_import_job(params = {}, = {}) req = build_request(:describe_fhir_import_job, params) req.send_request() end |
#list_fhir_datastores(params = {}) ⇒ Types::ListFHIRDatastoresResponse
List all FHIR-enabled data stores in a user’s account, regardless of data store status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
817 818 819 820 |
# File 'lib/aws-sdk-healthlake/client.rb', line 817 def list_fhir_datastores(params = {}, = {}) req = build_request(:list_fhir_datastores, params) req.send_request() end |
#list_fhir_export_jobs(params = {}) ⇒ Types::ListFHIRExportJobsResponse
Lists all FHIR export jobs associated with an account and their statuses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
889 890 891 892 |
# File 'lib/aws-sdk-healthlake/client.rb', line 889 def list_fhir_export_jobs(params = {}, = {}) req = build_request(:list_fhir_export_jobs, params) req.send_request() end |
#list_fhir_import_jobs(params = {}) ⇒ Types::ListFHIRImportJobsResponse
List all FHIR import jobs associated with an account and their statuses.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
971 972 973 974 |
# File 'lib/aws-sdk-healthlake/client.rb', line 971 def list_fhir_import_jobs(params = {}, = {}) req = build_request(:list_fhir_import_jobs, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all existing tags associated with a data store.
1002 1003 1004 1005 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1002 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_fhir_export_job(params = {}) ⇒ Types::StartFHIRExportJobResponse
Start a FHIR export job.
1060 1061 1062 1063 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1060 def start_fhir_export_job(params = {}, = {}) req = build_request(:start_fhir_export_job, params) req.send_request() end |
#start_fhir_import_job(params = {}) ⇒ Types::StartFHIRImportJobResponse
Start importing bulk FHIR data into an ACTIVE data store. The import job imports FHIR data found in the ‘InputDataConfig` object and stores processing results in the `JobOutputDataConfig` object.
1130 1131 1132 1133 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1130 def start_fhir_import_job(params = {}, = {}) req = build_request(:start_fhir_import_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Add a user-specifed key and value tag to a data store.
1163 1164 1165 1166 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1163 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Remove a user-specifed key and value tag from a data store.
1190 1191 1192 1193 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1190 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_fhir_datastore(params = {}) ⇒ Types::UpdateFHIRDatastoreResponse
<para>Update the properties of a FHIR-enabled data store.</para>
1268 1269 1270 1271 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1268 def update_fhir_datastore(params = {}, = {}) req = build_request(:update_fhir_datastore, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ————————- | ——————————— | ——– | ————- | | fhir_datastore_active | #describe_fhir_datastore | 60 | 360 | | fhir_datastore_deleted | #describe_fhir_datastore | 120 | 360 | | fhir_export_job_completed | #describe_fhir_export_job | 120 | 360 | | fhir_import_job_completed | #describe_fhir_import_job | 120 | 720 |
1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1386 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1394 1395 1396 |
# File 'lib/aws-sdk-healthlake/client.rb', line 1394 def waiter_names waiters.keys end |