Class: Aws::HealthLake::Types::CreateDataTransformationProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::CreateDataTransformationProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The request parameters for the CreateDataTransformationProfile
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key identifier used to encrypt the profile content at rest.
-
#profile_description ⇒ String
A human-readable description of the profile's purpose.
-
#profile_name ⇒ String
A name for the data transformation profile.
-
#source ⇒ Types::CreateDataTransformationProfileSource
The source for the initial profile content.
-
#source_format ⇒ String
The source data format that this profile converts from (Consolidated Clinical Document Architecture (C-CDA) or Comma-separated values (CSV)).
-
#tags ⇒ Hash<String,String>
The tags to associate with the profile at creation time.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key identifier used to encrypt the profile content at rest.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#profile_description ⇒ String
A human-readable description of the profile's purpose.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#profile_name ⇒ String
A name for the data transformation profile.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::CreateDataTransformationProfileSource
The source for the initial profile content. Specify a built-in starter profile, an existing profile version to clone, raw profile content for CI/CD workflows, or a sample data file in Amazon S3.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#source_format ⇒ String
The source data format that this profile converts from (Consolidated Clinical Document Architecture (C-CDA) or Comma-separated values (CSV)).
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the profile at creation time.
227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/aws-sdk-healthlake/types.rb', line 227 class CreateDataTransformationProfileRequest < Struct.new( :source_format, :source, :kms_key_id, :profile_description, :profile_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |