Class: Aws::HealthLake::Types::CreateDataTransformationProfileSource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Note:

CreateDataTransformationProfileSource is a union - when making an API calls you must set exactly one of the members.

The source for initial content when creating a data transformation profile. Specify exactly one variant: a built-in starter profile, an existing profile version to clone, raw profile content, or a sample data file.

Defined Under Namespace

Classes: ExistingVersionedProfileId, ProfileMapping, SampleData, StarterProfile, Unknown

Constant Summary collapse

SENSITIVE =
[:profile_mapping]

Instance Attribute Summary collapse

Instance Attribute Details

#existing_versioned_profile_idTypes::ExistingVersionedProfileSource

Creates the profile by cloning an existing profile at a specific version.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/aws-sdk-healthlake/types.rb', line 266

class CreateDataTransformationProfileSource < Struct.new(
  :starter_profile,
  :existing_versioned_profile_id,
  :profile_mapping,
  :sample_data,
  :unknown)
  SENSITIVE = [:profile_mapping]
  include Aws::Structure
  include Aws::Structure::Union

  class StarterProfile < CreateDataTransformationProfileSource; end
  class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end
  class ProfileMapping < CreateDataTransformationProfileSource; end
  class SampleData < CreateDataTransformationProfileSource; end
  class Unknown < CreateDataTransformationProfileSource; end
end

#profile_mappingTypes::ProfileMappingSource

Creates the profile from raw profile content that you provide directly. Use this variant for continuous integration and continuous delivery (CI/CD) workflows.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/aws-sdk-healthlake/types.rb', line 266

class CreateDataTransformationProfileSource < Struct.new(
  :starter_profile,
  :existing_versioned_profile_id,
  :profile_mapping,
  :sample_data,
  :unknown)
  SENSITIVE = [:profile_mapping]
  include Aws::Structure
  include Aws::Structure::Union

  class StarterProfile < CreateDataTransformationProfileSource; end
  class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end
  class ProfileMapping < CreateDataTransformationProfileSource; end
  class SampleData < CreateDataTransformationProfileSource; end
  class Unknown < CreateDataTransformationProfileSource; end
end

#sample_dataTypes::SampleDataSource

Creates the profile from a sample data file stored in Amazon S3. Valid only when the source format is Comma-separated values (CSV).



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/aws-sdk-healthlake/types.rb', line 266

class CreateDataTransformationProfileSource < Struct.new(
  :starter_profile,
  :existing_versioned_profile_id,
  :profile_mapping,
  :sample_data,
  :unknown)
  SENSITIVE = [:profile_mapping]
  include Aws::Structure
  include Aws::Structure::Union

  class StarterProfile < CreateDataTransformationProfileSource; end
  class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end
  class ProfileMapping < CreateDataTransformationProfileSource; end
  class SampleData < CreateDataTransformationProfileSource; end
  class Unknown < CreateDataTransformationProfileSource; end
end

#starter_profileTypes::StarterProfileSource

Creates the profile from a built-in starter profile. Valid only when the source format is Consolidated Clinical Document Architecture (C-CDA).



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/aws-sdk-healthlake/types.rb', line 266

class CreateDataTransformationProfileSource < Struct.new(
  :starter_profile,
  :existing_versioned_profile_id,
  :profile_mapping,
  :sample_data,
  :unknown)
  SENSITIVE = [:profile_mapping]
  include Aws::Structure
  include Aws::Structure::Union

  class StarterProfile < CreateDataTransformationProfileSource; end
  class ExistingVersionedProfileId < CreateDataTransformationProfileSource; end
  class ProfileMapping < CreateDataTransformationProfileSource; end
  class SampleData < CreateDataTransformationProfileSource; end
  class Unknown < CreateDataTransformationProfileSource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



266
267
268
# File 'lib/aws-sdk-healthlake/types.rb', line 266

def unknown
  @unknown
end