Class: Aws::HealthLake::Types::CreateFHIRDatastoreRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configurationTypes::AnalyticsConfiguration

The analytics configuration for the data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

An optional user-provided token to ensure API idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_nameString

The data store name (user-generated).

Returns:

  • (String)


332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_type_versionString

The FHIR release version supported by the data store. Current support is for version R4.

Returns:

  • (String)


332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_configurationTypes::IdentityProviderConfiguration

The identity provider configuration to use for the data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nlp_configurationTypes::NlpConfiguration

The natural language processing (NLP) configuration for the data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#preload_data_configTypes::PreloadDataConfig

An optional parameter to preload (import) open source Synthea FHIR data upon creation of the data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#profile_configurationTypes::ProfileConfiguration

The profile configuration for the data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sse_configurationTypes::SseConfiguration

The server-side encryption key configuration for a customer-provided encryption key specified for creating a data store.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The resource tags applied to a data store when it is created.

Returns:



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-healthlake/types.rb', line 332

class CreateFHIRDatastoreRequest < Struct.new(
  :datastore_name,
  :datastore_type_version,
  :sse_configuration,
  :preload_data_config,
  :client_token,
  :tags,
  :identity_provider_configuration,
  :analytics_configuration,
  :nlp_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end