Class: Aws::HealthLake::Types::DataTransformationProfileVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Contains summary information about a specific version of a data transformation profile. To retrieve profile content, call GetDataTransformationProfile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_descriptionString

A description of what changed in this version.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The timestamp when this version was last updated.

Returns:

  • (Time)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier of the profile.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

The name of the profile.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#source_formatString

The source data format that this profile converts from.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_formatString

The target output format of the profile.

Returns:

  • (String)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version number.

Returns:

  • (Integer)


453
454
455
456
457
458
459
460
461
462
463
# File 'lib/aws-sdk-healthlake/types.rb', line 453

class DataTransformationProfileVersionSummary < Struct.new(
  :profile_id,
  :version,
  :source_format,
  :target_format,
  :profile_name,
  :change_description,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end