Class: Aws::HealthLake::Types::DataTransformationProfileVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DataTransformationProfileVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Contains summary information about a specific version of a data
transformation profile. To retrieve profile content, call
GetDataTransformationProfile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_description ⇒ String
A description of what changed in this version.
-
#last_updated_at ⇒ Time
The timestamp when this version was last updated.
-
#profile_id ⇒ String
The unique identifier of the profile.
-
#profile_name ⇒ String
The name of the profile.
-
#source_format ⇒ String
The source data format that this profile converts from.
-
#target_format ⇒ String
The target output format of the profile.
-
#version ⇒ Integer
The version number.
Instance Attribute Details
#change_description ⇒ String
A description of what changed in this version.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp when this version was last updated.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the profile.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_name ⇒ String
The name of the profile.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#source_format ⇒ String
The source data format that this profile converts from.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#target_format ⇒ String
The target output format of the profile.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version number.
453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-healthlake/types.rb', line 453 class DataTransformationProfileVersionSummary < Struct.new( :profile_id, :version, :source_format, :target_format, :profile_name, :change_description, :last_updated_at) SENSITIVE = [] include Aws::Structure end |