Class: Aws::HealthLake::Types::DataTransformationS3Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DataTransformationS3Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The Amazon S3 output configuration for a data transformation job, including the output location and encryption settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The AWS Key Management Service (AWS KMS) key identifier used to encrypt the transformation job output written to Amazon S3.
-
#s3_uri ⇒ String
The Amazon S3 URI where AWS HealthLake writes the converted output files.
Instance Attribute Details
#kms_key_id ⇒ String
The AWS Key Management Service (AWS KMS) key identifier used to encrypt the transformation job output written to Amazon S3.
480 481 482 483 484 485 |
# File 'lib/aws-sdk-healthlake/types.rb', line 480 class DataTransformationS3Configuration < Struct.new( :s3_uri, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI where AWS HealthLake writes the converted output files.
480 481 482 483 484 485 |
# File 'lib/aws-sdk-healthlake/types.rb', line 480 class DataTransformationS3Configuration < Struct.new( :s3_uri, :kms_key_id) SENSITIVE = [] include Aws::Structure end |