Class: Aws::HealthLake::Types::DataTransformationS3Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DataTransformationS3Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The Amazon S3 output configuration for a data transformation job, including the output location and encryption settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key identifier used to encrypt the transformation job output written to Amazon S3.
-
#s3_uri ⇒ String
The Amazon S3 URI where HealthLake writes the converted output files.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Web Services Key Management Service (Amazon Web Services KMS) key identifier used to encrypt the transformation job output written to Amazon S3.
530 531 532 533 534 535 |
# File 'lib/aws-sdk-healthlake/types.rb', line 530 class DataTransformationS3Configuration < Struct.new( :s3_uri, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI where HealthLake writes the converted output files.
530 531 532 533 534 535 |
# File 'lib/aws-sdk-healthlake/types.rb', line 530 class DataTransformationS3Configuration < Struct.new( :s3_uri, :kms_key_id) SENSITIVE = [] include Aws::Structure end |