Class: Aws::HealthLake::Types::DatastoreBackupStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DatastoreBackupStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The backup status information for the data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_enabled_at ⇒ Time
The time backup was enabled on the data store.
-
#configuration ⇒ Types::BackupConfiguration
The backup configuration for the data store.
-
#earliest_restore_point ⇒ Time
The earliest point in time the data store can be restored to.
-
#latest_restore_point ⇒ Time
The latest point in time the data store can be restored to.
-
#scheduled_permanent_deletion_time ⇒ Time
The time the retained backup data is scheduled for permanent deletion.
Instance Attribute Details
#backup_enabled_at ⇒ Time
The time backup was enabled on the data store.
562 563 564 565 566 567 568 569 570 |
# File 'lib/aws-sdk-healthlake/types.rb', line 562 class DatastoreBackupStatus < Struct.new( :configuration, :backup_enabled_at, :earliest_restore_point, :latest_restore_point, :scheduled_permanent_deletion_time) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::BackupConfiguration
The backup configuration for the data store.
562 563 564 565 566 567 568 569 570 |
# File 'lib/aws-sdk-healthlake/types.rb', line 562 class DatastoreBackupStatus < Struct.new( :configuration, :backup_enabled_at, :earliest_restore_point, :latest_restore_point, :scheduled_permanent_deletion_time) SENSITIVE = [] include Aws::Structure end |
#earliest_restore_point ⇒ Time
The earliest point in time the data store can be restored to.
562 563 564 565 566 567 568 569 570 |
# File 'lib/aws-sdk-healthlake/types.rb', line 562 class DatastoreBackupStatus < Struct.new( :configuration, :backup_enabled_at, :earliest_restore_point, :latest_restore_point, :scheduled_permanent_deletion_time) SENSITIVE = [] include Aws::Structure end |
#latest_restore_point ⇒ Time
The latest point in time the data store can be restored to.
562 563 564 565 566 567 568 569 570 |
# File 'lib/aws-sdk-healthlake/types.rb', line 562 class DatastoreBackupStatus < Struct.new( :configuration, :backup_enabled_at, :earliest_restore_point, :latest_restore_point, :scheduled_permanent_deletion_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_permanent_deletion_time ⇒ Time
The time the retained backup data is scheduled for permanent deletion.
562 563 564 565 566 567 568 569 570 |
# File 'lib/aws-sdk-healthlake/types.rb', line 562 class DatastoreBackupStatus < Struct.new( :configuration, :backup_enabled_at, :earliest_restore_point, :latest_restore_point, :scheduled_permanent_deletion_time) SENSITIVE = [] include Aws::Structure end |