Class: Aws::HealthLake::Types::DatastoreProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::DatastoreProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The data store properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The analytics configuration for the data store.
-
#created_at ⇒ Time
The time the data store was created.
-
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) used in the creation of the data store.
-
#datastore_endpoint ⇒ String
The AWS endpoint for the data store.
-
#datastore_id ⇒ String
The data store identifier.
-
#datastore_name ⇒ String
The data store name.
-
#datastore_status ⇒ String
The data store status.
-
#datastore_type_version ⇒ String
The FHIR release version supported by the data store.
-
#error_cause ⇒ Types::ErrorCause
The error cause for the current data store operation.
-
#identity_provider_configuration ⇒ Types::IdentityProviderConfiguration
The identity provider selected during data store creation.
-
#nlp_configuration ⇒ Types::NlpConfiguration
The natural language processing (NLP) configuration for the data store.
-
#preload_data_config ⇒ Types::PreloadDataConfig
The preloaded Synthea data configuration for the data store.
-
#profile_configuration ⇒ Types::ProfileConfiguration
The profile configuration for the data store.
-
#sse_configuration ⇒ Types::SseConfiguration
The server-side encryption key configuration for a customer provided encryption key.
Instance Attribute Details
#analytics_configuration ⇒ Types::AnalyticsConfiguration
The analytics configuration for the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time the data store was created.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) used in the creation of the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_endpoint ⇒ String
The AWS endpoint for the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_name ⇒ String
The data store name.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_status ⇒ String
The data store status.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_type_version ⇒ String
The FHIR release version supported by the data store. Current support is for version ‘R4`.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#error_cause ⇒ Types::ErrorCause
The error cause for the current data store operation.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#identity_provider_configuration ⇒ Types::IdentityProviderConfiguration
The identity provider selected during data store creation.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#nlp_configuration ⇒ Types::NlpConfiguration
The natural language processing (NLP) configuration for the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#preload_data_config ⇒ Types::PreloadDataConfig
The preloaded Synthea data configuration for the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#profile_configuration ⇒ Types::ProfileConfiguration
The profile configuration for the data store.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |
#sse_configuration ⇒ Types::SseConfiguration
The server-side encryption key configuration for a customer provided encryption key.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/aws-sdk-healthlake/types.rb', line 241 class DatastoreProperties < Struct.new( :datastore_id, :datastore_arn, :datastore_name, :datastore_status, :created_at, :datastore_type_version, :datastore_endpoint, :sse_configuration, :preload_data_config, :identity_provider_configuration, :error_cause, :nlp_configuration, :analytics_configuration, :profile_configuration) SENSITIVE = [] include Aws::Structure end |