Class: Aws::HealthLake::Types::DatastoreProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The data store properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analytics_configurationTypes::AnalyticsConfiguration

<para>The analytics configuration for the data store.</para>



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time the data store was created.

Returns:

  • (Time)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_arnString

The Amazon Resource Name (ARN) used in the creation of the data store.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_endpointString

The AWS endpoint for the data store.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_nameString

The data store name.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_statusString

The data store status.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_type_versionString

The FHIR release version supported by the data store. Current support is for version ‘R4`.

Returns:

  • (String)


224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#error_causeTypes::ErrorCause

The error cause for the current data store operation.

Returns:



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_configurationTypes::IdentityProviderConfiguration

The identity provider selected during data store creation.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nlp_configurationTypes::NlpConfiguration

<para>The natural language processing (NLP) configuration for the data store.</para>



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#preload_data_configTypes::PreloadDataConfig

The preloaded Synthea data configuration for the data store.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#profile_configurationTypes::ProfileConfiguration

<para>The profile configuration for the data store.</para>



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sse_configurationTypes::SseConfiguration

The server-side encryption key configuration for a customer provided encryption key.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/aws-sdk-healthlake/types.rb', line 224

class DatastoreProperties < Struct.new(
  :datastore_id,
  :datastore_arn,
  :datastore_name,
  :datastore_status,
  :created_at,
  :datastore_type_version,
  :datastore_endpoint,
  :sse_configuration,
  :preload_data_config,
  :identity_provider_configuration,
  :error_cause,
  :nlp_configuration,
  :analytics_configuration,
  :profile_configuration)
  SENSITIVE = []
  include Aws::Structure
end