Class: Aws::HealthLake::Types::ImportJobProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The import job properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_role_arnString

The Amazon Resource Name (ARN) that grants AWS HealthLake access to the input data.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time the import job was completed.

Returns:

  • (Time)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::InputDataConfig

The input data configuration supplied when the import job was created.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The import job identifier.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The import job name.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_output_data_configTypes::OutputDataConfig

The output data configuration supplied when the export job was created.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_progress_reportTypes::JobProgressReport

Displays the progress of the import job, including total resources scanned, total resources imported, and total size of data imported.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The import job status.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

An explanation of any errors that might have occurred during the FHIR import job.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#submit_timeTime

The time the import job was submitted for processing.

Returns:

  • (Time)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end

#validation_levelString

The validation level of the import job.

Returns:

  • (String)


591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 591

class ImportJobProperties < Struct.new(
  :job_id,
  :job_name,
  :job_status,
  :submit_time,
  :end_time,
  :datastore_id,
  :input_data_config,
  :job_output_data_config,
  :job_progress_report,
  :data_access_role_arn,
  :message,
  :validation_level)
  SENSITIVE = []
  include Aws::Structure
end