Class: Aws::HealthLake::Types::ImportJobProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::ImportJobProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The import job properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants AWS HealthLake access to the input data.
-
#datastore_id ⇒ String
The data store identifier.
-
#end_time ⇒ Time
The time the import job was completed.
-
#input_data_config ⇒ Types::InputDataConfig
The input data configuration supplied when the import job was created.
-
#job_id ⇒ String
The import job identifier.
-
#job_name ⇒ String
The import job name.
-
#job_output_data_config ⇒ Types::OutputDataConfig
The output data configuration supplied when the export job was created.
-
#job_progress_report ⇒ Types::JobProgressReport
Displays the progress of the import job, including total resources scanned, total resources imported, and total size of data imported.
-
#job_status ⇒ String
The import job status.
-
#message ⇒ String
An explanation of any errors that might have occurred during the FHIR import job.
-
#submit_time ⇒ Time
The time the import job was submitted for processing.
-
#validation_level ⇒ String
The validation level of the import job.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants AWS HealthLake access to the input data.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time the import job was completed.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::InputDataConfig
The input data configuration supplied when the import job was created.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The import job identifier.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The import job name.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#job_output_data_config ⇒ Types::OutputDataConfig
The output data configuration supplied when the export job was created.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#job_progress_report ⇒ Types::JobProgressReport
Displays the progress of the import job, including total resources scanned, total resources imported, and total size of data imported.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The import job status.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
An explanation of any errors that might have occurred during the FHIR import job.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#submit_time ⇒ Time
The time the import job was submitted for processing.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |
#validation_level ⇒ String
The validation level of the import job.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/aws-sdk-healthlake/types.rb', line 574 class ImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :submit_time, :end_time, :datastore_id, :input_data_config, :job_output_data_config, :job_progress_report, :data_access_role_arn, :message, :validation_level) SENSITIVE = [] include Aws::Structure end |