Class: Aws::HealthLake::Types::InputDataConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Note:

InputDataConfig is a union - when making an API calls you must set exactly one of the members.

Note:

InputDataConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of InputDataConfig corresponding to the set member.

The import job input properties.

Direct Known Subclasses

S3Uri, Unknown

Defined Under Namespace

Classes: S3Uri, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_uriString

The ‘S3Uri` is the user-specified S3 location of the FHIR data to be imported into AWS HealthLake.

Returns:

  • (String)


604
605
606
607
608
609
610
611
612
613
# File 'lib/aws-sdk-healthlake/types.rb', line 604

class InputDataConfig < Struct.new(
  :s3_uri,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3Uri < InputDataConfig; end
  class Unknown < InputDataConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



604
605
606
# File 'lib/aws-sdk-healthlake/types.rb', line 604

def unknown
  @unknown
end