Class: Aws::HealthLake::Types::JobProgressReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::JobProgressReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The progress report for the import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#throughput ⇒ Float
The transaction rate the import job is processed at.
-
#total_files_converted ⇒ Integer
Number of CCDA files successfully transformed during the import's transformation phase.
-
#total_number_of_files_read_with_customer_error ⇒ Integer
The number of files that failed to be read from the S3 input bucket due to customer error.
-
#total_number_of_imported_files ⇒ Integer
The number of files imported.
-
#total_number_of_imported_non_fhir_files ⇒ Integer
The number of non-FHIR files imported.
-
#total_number_of_non_fhir_files_read_with_customer_error ⇒ Integer
The number of non-FHIR files that failed to be read from the S3 input bucket due to customer error.
-
#total_number_of_non_fhir_resources_imported ⇒ Integer
The number of non-FHIR resources imported.
-
#total_number_of_non_fhir_resources_scanned ⇒ Integer
The number of non-FHIR resources scanned from the S3 input bucket.
-
#total_number_of_non_fhir_resources_with_customer_error ⇒ Integer
The number of non-FHIR resources that failed due to customer error.
-
#total_number_of_resources_imported ⇒ Integer
The number of resources imported.
-
#total_number_of_resources_scanned ⇒ Integer
The number of resources scanned from the S3 input bucket.
-
#total_number_of_resources_with_customer_error ⇒ Integer
The number of resources that failed due to customer error.
-
#total_number_of_scanned_files ⇒ Integer
The number of files scanned from the S3 input bucket.
-
#total_number_of_scanned_non_fhir_files ⇒ Integer
The number of non-FHIR files scanned from the S3 input bucket.
-
#total_resources_generated ⇒ Integer
Number of FHIR resources produced by the transformation phase.
-
#total_size_of_scanned_files_in_mb ⇒ Float
The size (in MB) of files scanned from the S3 input bucket.
-
#total_size_of_scanned_non_fhir_files_in_mb ⇒ Float
The size (in MB) of non-FHIR files scanned from the S3 input bucket.
Instance Attribute Details
#throughput ⇒ Float
The transaction rate the import job is processed at.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_files_converted ⇒ Integer
Number of CCDA files successfully transformed during the import's transformation phase. Populated only for import jobs that use the two-Step-Function (transformation + ingestion) flow; null for legacy single-SF imports and for pure FHIR imports that skip transformation.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_files_read_with_customer_error ⇒ Integer
The number of files that failed to be read from the S3 input bucket due to customer error.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_imported_files ⇒ Integer
The number of files imported.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_imported_non_fhir_files ⇒ Integer
The number of non-FHIR files imported.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_non_fhir_files_read_with_customer_error ⇒ Integer
The number of non-FHIR files that failed to be read from the S3 input bucket due to customer error.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_non_fhir_resources_imported ⇒ Integer
The number of non-FHIR resources imported.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_non_fhir_resources_scanned ⇒ Integer
The number of non-FHIR resources scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_non_fhir_resources_with_customer_error ⇒ Integer
The number of non-FHIR resources that failed due to customer error.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_imported ⇒ Integer
The number of resources imported.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_scanned ⇒ Integer
The number of resources scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_with_customer_error ⇒ Integer
The number of resources that failed due to customer error.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_scanned_files ⇒ Integer
The number of files scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_number_of_scanned_non_fhir_files ⇒ Integer
The number of non-FHIR files scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_resources_generated ⇒ Integer
Number of FHIR resources produced by the transformation phase. Populated only for import jobs that use the two-Step-Function flow; null for legacy single-SF imports and for pure FHIR imports.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_size_of_scanned_files_in_mb ⇒ Float
The size (in MB) of files scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |
#total_size_of_scanned_non_fhir_files_in_mb ⇒ Float
The size (in MB) of non-FHIR files scanned from the S3 input bucket.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1246 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :total_number_of_scanned_non_fhir_files, :total_size_of_scanned_non_fhir_files_in_mb, :total_number_of_imported_non_fhir_files, :total_number_of_non_fhir_resources_scanned, :total_number_of_non_fhir_resources_imported, :total_number_of_non_fhir_resources_with_customer_error, :total_number_of_non_fhir_files_read_with_customer_error, :throughput, :total_files_converted, :total_resources_generated) SENSITIVE = [] include Aws::Structure end |