Class: Aws::HealthLake::Types::JobProgressReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::JobProgressReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The progress report for the import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#throughput ⇒ Float
The transaction rate the import job is processed at.
-
#total_number_of_files_read_with_customer_error ⇒ Integer
The number of files that failed to be read from the S3 input bucket due to customer error.
-
#total_number_of_imported_files ⇒ Integer
The number of files imported.
-
#total_number_of_resources_imported ⇒ Integer
The number of resources imported.
-
#total_number_of_resources_scanned ⇒ Integer
The number of resources scanned from the S3 input bucket.
-
#total_number_of_resources_with_customer_error ⇒ Integer
The number of resources that failed due to customer error.
-
#total_number_of_scanned_files ⇒ Integer
The number of files scanned from the S3 input bucket.
-
#total_size_of_scanned_files_in_mb ⇒ Float
The size (in MB) of files scanned from the S3 input bucket.
Instance Attribute Details
#throughput ⇒ Float
The transaction rate the import job is processed at.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_files_read_with_customer_error ⇒ Integer
The number of files that failed to be read from the S3 input bucket due to customer error.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_imported_files ⇒ Integer
The number of files imported.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_imported ⇒ Integer
The number of resources imported.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_scanned ⇒ Integer
The number of resources scanned from the S3 input bucket.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_resources_with_customer_error ⇒ Integer
The number of resources that failed due to customer error.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_number_of_scanned_files ⇒ Integer
The number of files scanned from the S3 input bucket.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |
#total_size_of_scanned_files_in_mb ⇒ Float
The size (in MB) of files scanned from the S3 input bucket.
665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-healthlake/types.rb', line 665 class JobProgressReport < Struct.new( :total_number_of_scanned_files, :total_size_of_scanned_files_in_mb, :total_number_of_imported_files, :total_number_of_resources_scanned, :total_number_of_resources_imported, :total_number_of_resources_with_customer_error, :total_number_of_files_read_with_customer_error, :throughput) SENSITIVE = [] include Aws::Structure end |