Class: Aws::HealthLake::Types::PublishDataTransformationProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The request parameters for the PublishDataTransformationProfile operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_descriptionString

A description of what changed or why this version is being published.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-healthlake/types.rb', line 1765

class PublishDataTransformationProfileRequest < Struct.new(
  :profile_id,
  :source_format,
  :from_existing_version,
  :change_description)
  SENSITIVE = []
  include Aws::Structure
end

#from_existing_versionInteger

The version number of a previously published version to republish as the new latest version. Use this parameter for rollback scenarios. If you omit this parameter, the service publishes the current DRAFT version.

Returns:

  • (Integer)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-healthlake/types.rb', line 1765

class PublishDataTransformationProfileRequest < Struct.new(
  :profile_id,
  :source_format,
  :from_existing_version,
  :change_description)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier of the profile to publish.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-healthlake/types.rb', line 1765

class PublishDataTransformationProfileRequest < Struct.new(
  :profile_id,
  :source_format,
  :from_existing_version,
  :change_description)
  SENSITIVE = []
  include Aws::Structure
end

#source_formatString

The source data format of the profile.

Returns:

  • (String)


1765
1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-healthlake/types.rb', line 1765

class PublishDataTransformationProfileRequest < Struct.new(
  :profile_id,
  :source_format,
  :from_existing_version,
  :change_description)
  SENSITIVE = []
  include Aws::Structure
end