Class: Aws::HealthLake::Types::PublishDataTransformationProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::PublishDataTransformationProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The request parameters for the PublishDataTransformationProfile
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_description ⇒ String
A description of what changed or why this version is being published.
-
#from_existing_version ⇒ Integer
The version number of a previously published version to republish as the new latest version.
-
#profile_id ⇒ String
The unique identifier of the profile to publish.
-
#source_format ⇒ String
The source data format of the profile.
Instance Attribute Details
#change_description ⇒ String
A description of what changed or why this version is being published.
1765 1766 1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1765 class PublishDataTransformationProfileRequest < Struct.new( :profile_id, :source_format, :from_existing_version, :change_description) SENSITIVE = [] include Aws::Structure end |
#from_existing_version ⇒ Integer
The version number of a previously published version to republish as the new latest version. Use this parameter for rollback scenarios. If you omit this parameter, the service publishes the current DRAFT version.
1765 1766 1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1765 class PublishDataTransformationProfileRequest < Struct.new( :profile_id, :source_format, :from_existing_version, :change_description) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the profile to publish.
1765 1766 1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1765 class PublishDataTransformationProfileRequest < Struct.new( :profile_id, :source_format, :from_existing_version, :change_description) SENSITIVE = [] include Aws::Structure end |
#source_format ⇒ String
The source data format of the profile.
1765 1766 1767 1768 1769 1770 1771 1772 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1765 class PublishDataTransformationProfileRequest < Struct.new( :profile_id, :source_format, :from_existing_version, :change_description) SENSITIVE = [] include Aws::Structure end |