Class: Aws::HealthLake::Types::StartDataTransformationJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

The request parameters for the StartDataTransformationJob operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error.

Returns:

  • (String)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#data_access_role_arnString

The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that AWS HealthLake assumes to read from and write to the specified Amazon S3 locations.

Returns:

  • (String)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#drift_detection_enabledBoolean

Specifies whether drift detection is enabled for this job. When enabled, AWS HealthLake writes a drift report to the output Amazon S3 location alongside the converted files.

Returns:

  • (Boolean)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::TransformationInputDataConfig

The Amazon S3 location and format of the source files to transform.



1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

A descriptive name for the data transformation job.

Returns:

  • (String)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::TransformationOutputDataConfig

The Amazon S3 output location and AWS Key Management Service (AWS KMS) encryption configuration.



1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier of the data transformation profile to use for conversion.

Returns:

  • (String)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provenance_enabledBoolean

Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job. When provenance is enabled, the service also generates related DocumentReference and Device resources. If you don't specify a value, the default is true. To disable provenance output, set this parameter to false.

Returns:

  • (Boolean)


1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
# File 'lib/aws-sdk-healthlake/types.rb', line 1944

class StartDataTransformationJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :client_token,
  :job_name,
  :profile_id,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end