Class: Aws::HealthLake::Types::StartDataTransformationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::StartDataTransformationJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
The request parameters for the StartDataTransformationJob operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that HealthLake assumes to read from and write to the specified Amazon S3 locations.
-
#drift_detection_enabled ⇒ Boolean
Specifies whether drift detection is enabled for this job.
-
#input_data_config ⇒ Types::TransformationInputDataConfig
The Amazon S3 location and format of the source files to transform.
-
#job_name ⇒ String
A descriptive name for the data transformation job.
-
#output_data_config ⇒ Types::TransformationOutputDataConfig
The Amazon S3 output location and Amazon Web Services Key Management Service (Amazon Web Services KMS) encryption configuration.
-
#profile_id ⇒ String
The unique identifier of the data transformation profile to use for conversion.
-
#provenance_enabled ⇒ Boolean
Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request but does not return an error.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that HealthLake assumes to read from and write to the specified Amazon S3 locations.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#drift_detection_enabled ⇒ Boolean
Specifies whether drift detection is enabled for this job. When enabled, HealthLake writes a drift report to the output Amazon S3 location alongside the converted files.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::TransformationInputDataConfig
The Amazon S3 location and format of the source files to transform.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
A descriptive name for the data transformation job.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::TransformationOutputDataConfig
The Amazon S3 output location and Amazon Web Services Key Management Service (Amazon Web Services KMS) encryption configuration.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the data transformation profile to use for conversion.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#provenance_enabled ⇒ Boolean
Specifies whether FHIR R4 Provenance resource generation is enabled
for this transformation job. When provenance is enabled, the service
also generates related DocumentReference and Device resources. If
you don't specify a value, the default is true. To disable
provenance output, set this parameter to false.
2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2150 class StartDataTransformationJobRequest < Struct.new( :input_data_config, :output_data_config, :data_access_role_arn, :client_token, :job_name, :profile_id, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |