Class: Aws::HealthLake::Types::StartFHIRExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::StartFHIRExportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#datastore_id ⇒ String
The data store identifier from which files are being exported.
-
#job_id ⇒ String
The export job identifier.
-
#job_status ⇒ String
The export job status.
Instance Attribute Details
#datastore_id ⇒ String
The data store identifier from which files are being exported.
1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1065 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The export job identifier.
1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1065 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The export job status.
1065 1066 1067 1068 1069 1070 1071 |
# File 'lib/aws-sdk-healthlake/types.rb', line 1065 class StartFHIRExportJobResponse < Struct.new( :job_id, :job_status, :datastore_id) SENSITIVE = [] include Aws::Structure end |