Class: Aws::HealthLake::Types::StartFHIRImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The optional user-provided token used for ensuring API idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#data_access_role_arnString

The Amazon Resource Name (ARN) that grants access permission to AWS HealthLake.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#drift_detection_enabledBoolean

A boolean value.

Returns:

  • (Boolean)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::InputDataConfig

The input properties for the import job request.



2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#input_formatString

A bounded-length string value.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The import job name.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#job_output_data_configTypes::OutputDataConfig

The output data configuration supplied when the export job was created.



2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

A bounded-length string value.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provenance_enabledBoolean

Specifies whether to enable provenance for the import job.

Returns:

  • (Boolean)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#validation_levelString

The validation level of the import job.

Returns:

  • (String)


2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/aws-sdk-healthlake/types.rb', line 2086

class StartFHIRImportJobRequest < Struct.new(
  :job_name,
  :input_data_config,
  :job_output_data_config,
  :datastore_id,
  :data_access_role_arn,
  :client_token,
  :validation_level,
  :profile_id,
  :input_format,
  :drift_detection_enabled,
  :provenance_enabled)
  SENSITIVE = []
  include Aws::Structure
end