Class: Aws::HealthLake::Types::StartFHIRImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::StartFHIRImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The optional user-provided token used for ensuring API idempotency.
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants access permission to AWS HealthLake.
-
#datastore_id ⇒ String
The data store identifier.
-
#drift_detection_enabled ⇒ Boolean
A boolean value.
-
#input_data_config ⇒ Types::InputDataConfig
The input properties for the import job request.
-
#input_format ⇒ String
A bounded-length string value.
-
#job_name ⇒ String
The import job name.
-
#job_output_data_config ⇒ Types::OutputDataConfig
The output data configuration supplied when the export job was created.
-
#profile_id ⇒ String
A bounded-length string value.
-
#provenance_enabled ⇒ Boolean
Specifies whether to enable provenance for the import job.
-
#validation_level ⇒ String
The validation level of the import job.
Instance Attribute Details
#client_token ⇒ String
The optional user-provided token used for ensuring API idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants access permission to AWS HealthLake.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#drift_detection_enabled ⇒ Boolean
A boolean value.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::InputDataConfig
The input properties for the import job request.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#input_format ⇒ String
A bounded-length string value.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The import job name.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#job_output_data_config ⇒ Types::OutputDataConfig
The output data configuration supplied when the export job was created.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
A bounded-length string value.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#provenance_enabled ⇒ Boolean
Specifies whether to enable provenance for the import job.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |
#validation_level ⇒ String
The validation level of the import job.
2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2086 class StartFHIRImportJobRequest < Struct.new( :job_name, :input_data_config, :job_output_data_config, :datastore_id, :data_access_role_arn, :client_token, :validation_level, :profile_id, :input_format, :drift_detection_enabled, :provenance_enabled) SENSITIVE = [] include Aws::Structure end |