Class: Aws::HealthLake::Types::TransformationJobProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-healthlake/types.rb

Overview

Contains the properties of a data transformation job, including its status, configuration, and progress information. You retrieve this structure by calling DescribeDataTransformationJob.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_role_arnString

The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants AWS HealthLake access to the specified Amazon S3 locations. AWS HealthLake assumes this role to read input files and write output files.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#drift_detection_enabledBoolean

Specifies whether drift detection is enabled for this job. When enabled, AWS HealthLake writes a drift report to the output Amazon S3 location alongside the converted files.

Returns:

  • (Boolean)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp when the job completed or failed.

Returns:

  • (Time)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::TransformationInputDataConfig

The Amazon S3 location and format of the source files for this job.



2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The unique identifier of the data transformation job.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the data transformation job.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#job_progress_reportTypes::TransformationJobProgressReport

The progress report for the data transformation job, including counts of files processed and resources generated.



2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

The current status of the data transformation job.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

An informational message about the job, such as an error description if the job failed.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::TransformationOutputDataConfig

The Amazon S3 location and encryption configuration for the converted output.



2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier of the data transformation profile used for this job.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

The name of the data transformation profile used for this job.

Returns:

  • (String)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#profile_versionInteger

The version number of the data transformation profile used for this job.

Returns:

  • (Integer)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#provenance_enabledBoolean

Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job. When provenance is enabled, the service also generates related DocumentReference and Device resources.

Returns:

  • (Boolean)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end

#submit_timeTime

The timestamp when the job was submitted.

Returns:

  • (Time)


2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
# File 'lib/aws-sdk-healthlake/types.rb', line 2327

class TransformationJobProperties < Struct.new(
  :job_id,
  :job_status,
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :submit_time,
  :job_name,
  :profile_id,
  :profile_name,
  :profile_version,
  :end_time,
  :drift_detection_enabled,
  :provenance_enabled,
  :message,
  :job_progress_report)
  SENSITIVE = []
  include Aws::Structure
end