Class: Aws::HealthLake::Types::TransformationJobProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::HealthLake::Types::TransformationJobProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-healthlake/types.rb
Overview
Contains the properties of a data transformation job, including its
status, configuration, and progress information. You retrieve this
structure by calling DescribeDataTransformationJob.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants AWS HealthLake access to the specified Amazon S3 locations.
-
#drift_detection_enabled ⇒ Boolean
Specifies whether drift detection is enabled for this job.
-
#end_time ⇒ Time
The timestamp when the job completed or failed.
-
#input_data_config ⇒ Types::TransformationInputDataConfig
The Amazon S3 location and format of the source files for this job.
-
#job_id ⇒ String
The unique identifier of the data transformation job.
-
#job_name ⇒ String
The name of the data transformation job.
-
#job_progress_report ⇒ Types::TransformationJobProgressReport
The progress report for the data transformation job, including counts of files processed and resources generated.
-
#job_status ⇒ String
The current status of the data transformation job.
-
#message ⇒ String
An informational message about the job, such as an error description if the job failed.
-
#output_data_config ⇒ Types::TransformationOutputDataConfig
The Amazon S3 location and encryption configuration for the converted output.
-
#profile_id ⇒ String
The unique identifier of the data transformation profile used for this job.
-
#profile_name ⇒ String
The name of the data transformation profile used for this job.
-
#profile_version ⇒ Integer
The version number of the data transformation profile used for this job.
-
#provenance_enabled ⇒ Boolean
Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job.
-
#submit_time ⇒ Time
The timestamp when the job was submitted.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants AWS HealthLake access to the specified Amazon S3 locations. AWS HealthLake assumes this role to read input files and write output files.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#drift_detection_enabled ⇒ Boolean
Specifies whether drift detection is enabled for this job. When enabled, AWS HealthLake writes a drift report to the output Amazon S3 location alongside the converted files.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The timestamp when the job completed or failed.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::TransformationInputDataConfig
The Amazon S3 location and format of the source files for this job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The unique identifier of the data transformation job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the data transformation job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#job_progress_report ⇒ Types::TransformationJobProgressReport
The progress report for the data transformation job, including counts of files processed and resources generated.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The current status of the data transformation job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
An informational message about the job, such as an error description if the job failed.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#output_data_config ⇒ Types::TransformationOutputDataConfig
The Amazon S3 location and encryption configuration for the converted output.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier of the data transformation profile used for this job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#profile_name ⇒ String
The name of the data transformation profile used for this job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#profile_version ⇒ Integer
The version number of the data transformation profile used for this job.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#provenance_enabled ⇒ Boolean
Specifies whether FHIR R4 Provenance resource generation is enabled for this transformation job. When provenance is enabled, the service also generates related DocumentReference and Device resources.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |
#submit_time ⇒ Time
The timestamp when the job was submitted.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 |
# File 'lib/aws-sdk-healthlake/types.rb', line 2327 class TransformationJobProperties < Struct.new( :job_id, :job_status, :input_data_config, :output_data_config, :data_access_role_arn, :submit_time, :job_name, :profile_id, :profile_name, :profile_version, :end_time, :drift_detection_enabled, :provenance_enabled, :message, :job_progress_report) SENSITIVE = [] include Aws::Structure end |