Class: Aws::HealthLake::Waiters::FHIRImportJobCompleted
- Inherits:
-
Object
- Object
- Aws::HealthLake::Waiters::FHIRImportJobCompleted
- Defined in:
- lib/aws-sdk-healthlake/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FHIRImportJobCompleted
constructor
A new instance of FHIRImportJobCompleted.
-
#wait(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FHIRImportJobCompleted
Returns a new instance of FHIRImportJobCompleted.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 235 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 720, delay: 120, poller: Aws::Waiters::Poller.new( operation_name: :describe_fhir_import_job, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "import_job_properties.job_status", "expected" => "COMPLETED" }, { "state" => "success", "matcher" => "path", "argument" => "import_job_properties.job_status", "expected" => "COMPLETED_WITH_ERRORS" }, { "state" => "failure", "matcher" => "path", "argument" => "import_job_properties.job_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
273 274 275 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 273 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeFHIRImportJobResponse
Returns a response object which responds to the following methods:
-
#import_job_properties => Types::ImportJobProperties
268 269 270 |
# File 'lib/aws-sdk-healthlake/waiters.rb', line 268 def wait(params = {}) @waiter.wait(client: @client, params: params) end |